@@ -4,6 +4,8 @@
 
 - CURRENT_DIRECTORY: directory with all the code
 
+- HOME_DIRECTORY: home directory
+
 - CACHE_DIRECTORY: directory used to store the cache datasets
 """
 from pathlib import Path
@@ -11,7 +13,8 @@ from pathlib import Path
 CURRENT_DIRECTORY = Path(__file__).resolve().parent
 ROOT_DIRECTORY = CURRENT_DIRECTORY.parent
 
-CACHE_DIRECTORY = CURRENT_DIRECTORY / ".cache"
+HOME_DIRECTORY = Path.home()
+CACHE_DIRECTORY = HOME_DIRECTORY / ".cache" / "bio-datasets"
 
 from .dataset import list_datasets  # noqa: E402
 from .dataset import load_dataset  # noqa: E402
